# -*- coding: utf-8 -*-
"""
@Time    : 2025/6/11 09:23
@Author  : QIN2DIM
@GitHub  : https://github.com/QIN2DIM
@Desc    :
"""
from pathlib import Path

STORAGE_DIR = Path("stats")
STATS_EXCEL_FILENAME = "docker_compose_all_services.xlsx"
STATS_VIS_FILENAME = "merged_service_network.html"
